# -*- coding: utf-8 -*-
# Generated by Django 1.11.16 on 2018-10-09 12:25
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Address',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('address', models.EmailField(max_length=254, unique=True)),
                ('comment', models.CharField(blank=True, max_length=66, null=True)),
            ],
            options={
                'verbose_name_plural': 'addresses',
            },
        ),
        migrations.CreateModel(
            name='Mail',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.SlugField(max_length=40, unique=True)),
                ('bccs', models.ManyToManyField(blank=True, related_name='bcc', to='mailrobot.Address')),
                ('ccs', models.ManyToManyField(blank=True, related_name='cc', to='mailrobot.Address')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='MailBody',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.SlugField(max_length=40, unique=True)),
                ('subject', models.CharField(max_length=66)),
                ('body', models.TextField()),
            ],
            options={
                'verbose_name_plural': 'mailbodies',
            },
        ),
        migrations.CreateModel(
            name='Signature',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.SlugField(max_length=40, unique=True)),
                ('sig', models.TextField()),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AddField(
            model_name='mail',
            name='content',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='mail', to='mailrobot.MailBody'),
        ),
        migrations.AddField(
            model_name='mail',
            name='recipients',
            field=models.ManyToManyField(blank=True, related_name='recipients', to='mailrobot.Address'),
        ),
        migrations.AddField(
            model_name='mail',
            name='reply_to',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='reply_to', to='mailrobot.Address'),
        ),
        migrations.AddField(
            model_name='mail',
            name='sender',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='sender', to='mailrobot.Address'),
        ),
        migrations.AddField(
            model_name='mail',
            name='signature',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='mail', to='mailrobot.Signature'),
        ),
    ]
